package com.jjt.calc.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.calc.domain.TwinCalcDayYhj;

import java.util.List;

/**
 * 印花机日统计数据Mapper接口
 *
 * @author wukai
 * @date 2025-03-07
 */
public interface TwinCalcDayYhjMapper extends BaseMapper<TwinCalcDayYhj> {
    /**
     * 查询印花机日统计数据
     *
     * @param id 印花机日统计数据主键
     * @return 印花机日统计数据
     */
    public TwinCalcDayYhj selectTwinCalcDayYhjById(Long id);

    /**
     * 查询印花机日统计数据列表
     *
     * @param twinCalcDayYhj 印花机日统计数据
     * @return 印花机日统计数据集合
     */
    public List<TwinCalcDayYhj> selectTwinCalcDayYhjList(TwinCalcDayYhj twinCalcDayYhj);

    /**
     * 新增印花机日统计数据
     *
     * @param twinCalcDayYhj 印花机日统计数据
     * @return 结果
     */
    public int insertTwinCalcDayYhj(TwinCalcDayYhj twinCalcDayYhj);

    /**
     * 修改印花机日统计数据
     *
     * @param twinCalcDayYhj 印花机日统计数据
     * @return 结果
     */
    public int updateTwinCalcDayYhj(TwinCalcDayYhj twinCalcDayYhj);

    /**
     * 删除印花机日统计数据
     *
     * @param id 印花机日统计数据主键
     * @return 结果
     */
    public int deleteTwinCalcDayYhjById(Long id);

    /**
     * 批量删除印花机日统计数据
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinCalcDayYhjByIds(Long[] ids);

    /**
     * 根据时间删除
     * @param date  日期
     */
    void delete4date(String date);
}
