package com.jjt.calc.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.calc.domain.TwinCalcDayYhj;
import com.jjt.calc.service.ITwinCalcDayYhjService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 印花机日统计数据Controller
 *
 * @author wukai
 * @date 2025-03-07
 */
@Api(tags="印花机日统计数据")
@RestController
@RequestMapping("/calc/dayYhj")
public class TwinCalcDayYhjController extends BaseController{
    @Resource
    private ITwinCalcDayYhjService twinCalcDayYhjService;

    /**
     * 查询印花机日统计数据列表
     */
    @ApiOperation("查询印花机日统计数据列表")
    @PreAuthorize("@ss.hasPermi('calc:dayYhj:list')")
    @GetMapping("/list")
    public TableDataInfo list(TwinCalcDayYhj twinCalcDayYhj)
    {
        startPage();
        List<TwinCalcDayYhj> list = twinCalcDayYhjService.selectTwinCalcDayYhjList(twinCalcDayYhj);
        return getDataTable(list);
    }

    /**
     * 导出印花机日统计数据列表
     */
    @ApiOperation("导出印花机日统计数据列表")
    @PreAuthorize("@ss.hasPermi('calc:dayYhj:export')")
    @Log(title = "印花机日统计数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TwinCalcDayYhj twinCalcDayYhj)
    {
        List<TwinCalcDayYhj> list = twinCalcDayYhjService.selectTwinCalcDayYhjList(twinCalcDayYhj);
        ExcelUtil<TwinCalcDayYhj> util = new ExcelUtil<TwinCalcDayYhj>(TwinCalcDayYhj.class);
        util.exportExcel(response, list, "印花机日统计数据数据");
    }

    /**
     * 获取印花机日统计数据详细信息
     */
    @ApiOperation("获取印花机日统计数据详细信息")
    @PreAuthorize("@ss.hasPermi('calc:dayYhj:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(twinCalcDayYhjService.selectTwinCalcDayYhjById(id));
    }

    /**
     * 新增印花机日统计数据
     */
    @ApiOperation("新增印花机日统计数据")
    @PreAuthorize("@ss.hasPermi('calc:dayYhj:add')")
    @Log(title = "印花机日统计数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TwinCalcDayYhj twinCalcDayYhj)
    {
        return toAjax(twinCalcDayYhjService.insertTwinCalcDayYhj(twinCalcDayYhj));
    }

    /**
     * 修改印花机日统计数据
     */
    @ApiOperation("修改印花机日统计数据")
    @PreAuthorize("@ss.hasPermi('calc:dayYhj:edit')")
    @Log(title = "印花机日统计数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TwinCalcDayYhj twinCalcDayYhj)
    {
        return toAjax(twinCalcDayYhjService.updateTwinCalcDayYhj(twinCalcDayYhj));
    }

    /**
     * 删除印花机日统计数据
     */
    @ApiOperation("删除印花机日统计数据")
    @PreAuthorize("@ss.hasPermi('calc:dayYhj:remove')")
    @Log(title = "印花机日统计数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(twinCalcDayYhjService.deleteTwinCalcDayYhjByIds(ids));
    }
}
